#
# spec file for package patterns-microos
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%if 0%{?is_opensuse}
%define prodname openSUSE Leap Micro
%else
%define prodname SUSE Linux Enterprise Micro
%endif

Name:           patterns-microos
Version:        5.5.1
Release:        150500.1.1
Summary:        Patterns for %{prodname}
License:        MIT
Group:          Metapackages
URL:            http://en.opensuse.org/Patterns
Source0:        %{name}-rpmlintrc
ExclusiveArch:  x86_64 armv7l armv7hl aarch64 ppc64le s390x

%description
This is an internal package that is used to create the patterns as part
of the installation source setup. Installation of this package does
not make sense.

%package basesystem
Summary:        %{prodname} Base System (alias pattern for microos-base)
Group:          Metapackages
Provides:       pattern() = basesystem
Provides:       pattern-icon() = pattern-kubic
Requires:       pattern() = microos-base
Obsoletes:	patterns-base-basesystem

%description basesystem
This is the %{prodname} runtime system. It contains only a minimal multiuser
booting system.

%package base
Summary:        %{prodname}
Group:          Metapackages
Provides:       pattern() = microos-base
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-kubic
Provides:       pattern-order() = 9010
Provides:       pattern-visible()
Requires:       distribution-release
Requires:       aaa_base
Requires:       audit
Requires:       bash
Requires:       btrfsmaintenance
Requires:       btrfsprogs
Requires:       ca-certificates
Requires:       ca-certificates-mozilla
Requires:       chrony
Requires:       coreutils
Requires:       cracklib-dict-small
Requires:       dosfstools
Requires:       dracut
Requires:       elfutils
Requires:       filesystem
Requires:       glibc
Requires:       haveged
Requires:       health-checker
Requires:       health-checker-plugins-MicroOS
Requires:       hwinfo
Requires:       iputils
### bsc#1174393
Requires:       issue-generator
Requires:       kbd
Requires:       kdump
#Requires:       kernel-base
Requires:       kmod
Requires:       glibc-locale-base
Requires:       less
Requires:       libnss_usrfiles2
Requires:       login
Requires:       logrotate
Requires:       microos-tools
### not in SLES Requires:       nano
Requires:       net-tools
Requires:       openssh
Requires:       pam
Requires:       parted
Requires:       pkgconfig
Requires:       procps
Requires:       rebootmgr
Requires:       rpm
Requires:       shadow
Requires:       snapper
Requires:       sudo
Requires:       supportutils
Requires:       sysconfig
Requires:       sysfsutils
#Requires:       branding-SLE
# FIX branding to similar to SLES
%ifnarch s390x
Requires:	grub2-branding
%endif
Requires:       system-group-hardware
Requires:       system-group-wheel
Requires:       system-group-kvm
Requires:       system-user-nobody
Requires:       systemd
Requires:       systemd-presets-branding-SMO
### not in SLES Requires:       tallow
Requires:       terminfo
Requires:       timezone
Requires:       transactional-update
Requires:       transactional-update-zypp-config
Requires:       udev
Requires:       vlan
Requires:       which
Requires:       xfsprogs
Requires:       yast2-logs
Requires:       zypper
Requires:       zypper-needs-restarting
Requires:	vim-small
### not in SLES Requires:       pattern() = bootloader
Conflicts:      gettext-runtime-mini
Conflicts:      krb5-mini
# jsc#SMO-79
Requires:	tpm2.0-tools
Requires:	tpm2.0-abrmd
Requires:	tpm2-0-tss
Requires:	tpm2-tss-engine
# jsc#SMO-50
%ifarch x86_64 aarch64
Requires:	libmbim
Requires:	libmbim-glib4
Requires:	libqmi-tools
Requires:	libqmi-glib5
%endif
# jsc#CSD-121
Requires:	udica
# jsc#SMO-120
Requires:	pam_u2f
%ifarch s390x
Requires:	libica
Requires:	openCryptoki
Requires:	openssl-ibmca
%endif


%description base
This is the %{prodname} runtime system. It contains only a minimal multiuser
booting system.

%package defaults
Summary:        %{prodname} defaults
Group:          Metapackages
Provides:       pattern() = microos-defaults
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-kubic
Provides:       pattern-order() = 9011
Requires:       pattern() = microos-base
Requires:       pattern() = microos-bootloader
Requires:       suseconnect-ng
Requires:       rollback-helper

%description defaults
This provides default packages for %{prodname} which can be optionally
replaced by alternatives.

%package hardware
Summary:        Hardware Support
Group:          Metapackages
Provides:       pattern() = microos-hardware
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-kubic
Provides:       pattern-order() = 9030
Provides:       pattern-visible()
Requires:       fcoe-utils
Requires:       kernel-firmware-all
#Obsolete CaaSP Patterns
Provides:       patterns-caasp-hardware
Obsoletes:      patterns-caasp-hardware <= 4.0
#%ifarch armv7l armv7hl
#Requires:       kernel-lpae
#%else
#Requires:       kernel-default
#%endif
%ifnarch s390x
Requires:       irqbalance
%endif

%description hardware
Packages required to install %{prodname} on real hardware.

%package bootloader
Summary:        Bootloader
Group:          Metapackages
Provides:       pattern() = microos-bootloader
#
Requires:       grub2
Requires:       (grub2-snapper-plugin if snapper)
%ifarch x86_64
# XXX: not sure this really belongs here. More like a kernel
# rather than bootloader related thing?
Requires:       biosdevname
%endif
%ifnarch s390x ppc64 ppc64le
Requires:       (grub2-branding-openSUSE if branding-openSUSE)
%endif
%ifarch x86_64
Requires:       grub2-x86_64-efi
%endif
%ifarch aarch64
Requires:       grub2-arm64-efi
%endif
%ifarch armv7l armv7hl
Requires:       grub2-arm-efi
Requires:       grub2-arm-uboot
%endif
%ifarch aarch64 x86_64
Requires:       mokutil
Requires:       shim
%endif

%description bootloader
This pattern holds files required for booting the system

%package selinux
Summary:        SELinux Support
Group:          Metapackages
Provides:       pattern() = microos-selinux
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9055
Provides:       pattern-visible()
Requires:       container-selinux
Requires:       policycoreutils
Requires:       selinux-policy-targeted
Requires:       selinux-tools

%description selinux
This are packages which are required to enable SELinux on
%{prodname}

%package salt_minion
Summary:        Salt Minion
Group:          Metapackages
Provides:       pattern() = microos-salt_minion
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9901
Provides:       pattern-visible()
Requires:       salt-minion

%description salt_minion
Packages to manage the host using Salt or management solutions which utilize Salt, e.g. SUSE Manager

%package kvm_host
Summary:        KVM Virtualization Host
Group:          Metapackages
Provides:       pattern() = microos-kvm_host
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9050
Provides:       pattern-visible()
Requires:       guestfs-tools
Requires:       python3-libvirt-python
Requires:       qemu-tools

# fix issue because qemu-kvm is not present on all arch and 
# we would like to deprecate it for the futur (will be only
# updated if already installed on the system)
%ifarch %ix86 x86_64
Requires:       qemu-x86
%endif
%ifarch ppc ppc64 ppc64le
Requires:       qemu-ppc
%endif
%ifarch s390x
Requires:       qemu-s390
%endif
%ifarch %arm aarch64 armv7hl
Requires:       qemu-arm
Requires:       qemu-ipxe
%endif
Requires:       tftp
Requires:       libvirt-daemon-qemu
Recommends:     tigervnc
Recommends:     virt-install
Recommends:     vm-install
Requires:	netcat-openbsd
Requires:	gnutls
Requires:	libvirt-client


%description kvm_host
Packages to run virtual machines using the KVM hypervisor

%package container_runtime
Summary:        Container Runtime for non-clustered systems
Group:          Metapackages
Provides:       pattern() = microos-container_runtime
Provides:       pattern-category() = Containers
Provides:       pattern-icon() = pattern-kubic
Provides:       pattern-order() = 9040
Provides:       pattern-visible()
#Obsolete CaaSP Patterns
Provides:       patterns-caasp-container-runtime
Obsoletes:      patterns-caasp-container-runtime <= 4.0
Requires:       podman
Requires:       podman-cni-config
Requires:       toolbox
Requires:       pattern() = basesystem
%if !0%{?is_opensuse}
Requires:       libcontainers-sles-mounts
%endif

%description container_runtime
This pattern installs the default container runtime packages for non-clustered systems.

%package cockpit
Summary: Web based remote system management
Group: Metapackages
Provides: pattern() = microos-cockpit
Provides: pattern-category() = MicroOS
Provides: pattern-icon() = pattern-generic
Provides: pattern-order() = 9060
Provides: pattern-visible()
Requires: cockpit-system
Requires: cockpit-ws
Requires: cockpit
Requires: (cockpit-networkmanager or cockpit-wicked)
Conflicts: (cockpit-networkmanager and cockpit-wicked)
Recommends: (cockpit-networkmanager if NetworkManager)
Recommends: (cockpit-wicked if wicked)
Requires: cockpit-tukit
Requires: (cockpit-podman if podman)
Requires: (cockpit-machines if libvirt-daemon-qemu)
Requires: cockpit-storaged
Requires: libudisks2-0_btrfs
Requires: libudisks2-0_lvm2
Requires: cockpit-selinux
%if 0%{?is_opensuse}
Requires: cockpit-branding-openSUSE-Leap-Micro
%endif

%description cockpit
Packages required to run the Cockpit system management service.
For the web service the cockpit-ws container is required.

%package sssd_ldap
Summary:        LDAP client
Group:          Metapackages
Provides:       pattern() = microos-sssd_ldap
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9070
Provides:       pattern-visible()
Requires:       sssd
Requires:       sssd-ldap

%description sssd_ldap
Packages required to enable LDAP client support via sssd on
%{prodname}.

%package fips
Summary:        FIPS 140-2 specific packages
Group:          Metapackages
Provides:       pattern() = microos-fips
Provides:       pattern-category() = MicroOS
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9090
Provides:       pattern-visible()
Provides:       patterns-sles-fips = %{version}
Obsoletes:      patterns-sles-fips < %{version}
Provides:       patterns-server-enterprise-fips = %{version}
Obsoletes:      patterns-server-enterprise-fips < %{version}
Provides:       patterns-server-enterprise-fips-32bit = %{version}
Obsoletes:      patterns-server-enterprise-fips-32bit < %{version}

Requires:       (dracut-fips if dracut)
Requires:       (libcryptsetup12-hmac if libcryptsetup12)
Requires:       (libcryptsetup12-hmac-32bit if libcryptsetup12-32bit)
Requires:       (libfreebl3-hmac if libfreebl3)
Requires:       (libfreebl3-hmac-32bit if libfreebl3-32bit)
Requires:       (libgcrypt20-hmac if libgcrypt20)
Requires:       (libgnutls30-hmac if libgnutls30)
Requires:       (libgnutls30-hmac-32bit if libgnutls30-32bit)
Requires:       (libopenssl1_0_0-hmac if libopenssl1_0_0)
Requires:       (libopenssl1_0_0-hmac-32bit if libopenssl1_0_0-32bit)
Requires:       (libopenssl1_1-hmac if libopenssl1_1)
Requires:       (libopenssl1_1-hmac-32bit if libopenssl1_1-32bit)
Requires:       (libsoftokn3-hmac if libsoftokn3)
Requires:       (libsoftokn3-hmac-32bit if libsoftokn3-32bit)
Requires:       (openssh-fips if openssh-clients)
Requires:       (openssh-fips if openssh-server)
Requires:       (strongswan-hmac if strongswan)

%description fips
This pattern installs the FIPS 140-2 specific packages that complete the various
cryptographic modules in use. It is required if you want to run the
machine with "fips=1".

Please note that this pattern only enables FIPS 140-2 compliant operation, it does
not directly make the system FIPS 140-2 certified nor validated.

Please refer to SUSE official statements on the state of FIPS 140-2 certification.


%prep
# empty on purpose

%build
# empty on purpose

%install
mkdir -p %{buildroot}%{_docdir}/patterns-microos/
for i in basesystem base defaults hardware bootloader selinux salt_minion kvm_host container_runtime cockpit sssd_ldap fips; do
	echo "This file marks the pattern $i to be installed." >%{buildroot}%{_docdir}/patterns-microos/$i.txt
done

%files basesystem
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/basesystem.txt

%files base
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/base.txt

%files defaults
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/defaults.txt

%files hardware
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/hardware.txt

%files bootloader
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/bootloader.txt

%files selinux
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/selinux.txt

%files salt_minion
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/salt_minion.txt

%files kvm_host
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/kvm_host.txt

%files container_runtime
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/container_runtime.txt

%files cockpit
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/cockpit.txt

%files sssd_ldap
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/sssd_ldap.txt

%files fips
%dir %{_docdir}/patterns-microos
%{_docdir}/patterns-microos/fips.txt

%changelog
* Wed Sep 13 2023 jsrain@suse.com
- include libcontainers-sles-mounts in SLE-Micro (bsc#1215291)
- 5.5.1
* Tue Sep  5 2023 jsrain@localhost
- include netcat-openbsd gnutls libvirt-client in KVM pattern
  (bsc#1214825, bsc#1214827)
- 5.5.0
* Mon Mar 13 2023 jsrain@suse.com
- include libica based cryptographic acceleration for s/390x
  (jsc#SMO-208)
- 5.4.0
* Tue Sep 20 2022 jsrain@suse.com
- removed cockpit-kdump which is not yet ready
- 5.3.9
* Fri Sep  9 2022 jsrain@suse.com
- added cockpit-selinux (jsc#CSD-77)
- 5.3.8
* Mon Sep  5 2022 jsrain@suse.com
- added cockpit-kdump (jsc#SMO-166)
- 5.3.7
* Fri Aug 26 2022 jsrain@suse.com
- updating the cockpit network plug-in dependencies (bsc#1202479)
- 5.3.6
* Thu Aug 25 2022 jsrain@suse.com
- added libudisks2-0_lvm2 and _btrfs (jsc#SMO-154, jsc#SMO-161)
- 5.3.5
* Wed Aug 10 2022 jsrain@suse.com
- add cockpit-storaged (jsc#SMO-116)
- add libmbim libmbim-glib4 libqmi-tools libqmi-glib5 (jsc#SMO-50)
- add udica (jsc#CSD-121) pam_u2f (jsc#SMO-120)
- 5.3.4
* Wed Jun 22 2022 jsrain@suse.com
- added conditionally cockpit-networkmanager to cockpit pattern
- removed wicked from base pattern (jsc#SMO-84)
- 5.3.3
* Tue Jun 21 2022 jsrain@suse.com
- added cockpit-tukit to the pattern (jsc#SMO-22)
- 5.3.2
* Tue Jun  7 2022 jsrain@suse.com
- include TPM in the base pattern (jsc#SMO-79)
- 5.3.1
* Tue May 24 2022 jsrain@suse.com
- bump version to 5.3.0
* Tue Mar  1 2022 jsrain@suse.com
- make the salt_minion pattern visible
- 5.2.1
* Wed Feb  2 2022 jsrain@suse.com
- bump version to 5.2.0
- specify branding of systemd presets
* Tue Feb  1 2022 jsrain@suse.com
- rename pattern microos_sssd_ldap to microos-sssd_ldap
  (bsc#1192462)
* Sat Jan 29 2022 jsrain@suse.com
- remove cockpit-dashboard (jsc#SMO-70)
- include cockpit-machines (jsc#SMO-46)
* Sun Dec 19 2021 jsrain@suse.com
- do not require kernel-default (bsc#1193955)
* Wed Nov  3 2021 Ludwig Nussel <lnussel@suse.de>
- adjustments to be able to build for Leap (boo#1192518)
* Thu Sep  9 2021 jsrain@suse.com
- added the FIPS pattern (matching the one from SLES)
* Fri Aug 27 2021 jsrain@suse.com
- zypper-migration-plug-in now provided by suseconnect-ng
* Thu Aug 26 2021 jsrain@suse.com
- added sssd_ldap pattern
* Mon Aug 16 2021 jsrain@suse.com
- remove the microos-k3s pattern
* Tue Jul 20 2021 jsrain@suse.com
- re-add rollback-helper
* Mon Jul 19 2021 jsrain@suse.com
- use suseconnect-ng (jsc#SMO-35)
- temporarily remove rollback-helper and zypper-migration-plugin
* Mon Jul 19 2021 jsrain@suse.com
- added bootloader pattern (bsc#1188351)
* Thu Jun 17 2021 jsrain@suse.com
- create pattern for k3s (jsc#SMO-40)
* Thu Jun  3 2021 jsrain@suse.com
- add zypper-migration-plugin to the default pattern (bsc#1186791)
* Fri Apr  9 2021 jsrain@suse.com
- require kernel-firmware-all for compressed firmware
* Wed Apr  7 2021 jsrain@suse.com
- require the libvirt-daemon-qemu package (bsc#1184435)
- bump version to 5.1
* Wed Mar 10 2021 jsrain@suse.com
- include rollback-helper in the default patterns (bsc#1183228)
* Mon Feb 22 2021 jsrain@suse.com
- added cockpit-dashboard to cockpit pattern
* Mon Feb 15 2021 jsrain@suse.com
- remove systemd-logger from pattern
* Thu Feb  4 2021 jsrain@suse.com
- include SUSEConnect in the default pattern (bsc#1181714)
* Fri Jan 29 2021 jsrain@suse.com
- include the cockpit-podman plug-in
* Thu Jan 28 2021 jsrain@suse.com
- added the cockpit-wicked plug-in
* Wed Jan 27 2021 jsrain@suse.com
- don't require grub2-branding on s390x
* Mon Jan 18 2021 jsrain@suse.com
- include the cockpit package in the pattern
* Thu Jan 14 2021 jsrain@suse.com
- added system-group-kvm
* Wed Jan 13 2021 jsrain@suse.com
- adjust pattern descriptions to product rename
* Mon Dec  7 2020 jsrain@suse.com
- include cockpit-ws in the cockpit pattern
- typo in pattern provides
* Fri Nov 27 2020 jsrain@suse.com
- created pattern cockpit
* Wed Nov 25 2020 jsrain@suse.com
- added vim-small to the default pattern
* Thu Oct 29 2020 jsrain@suse.com
- removing plymouth
* Wed Oct 21 2020 jsrain@suse.com
- updated selinux pattern for new version
* Fri Oct 16 2020 jsrain@suse.com
- adjusted pattern ordering
* Wed Oct 14 2020 jsrain@suse.com
- renamed to patterns-microos
* Fri Oct  9 2020 jsrain@suse.com
- include plymouth in the pattern
* Wed Sep 30 2020 jsrain@suse.com
- do not obsolete the suse-build-key (bsc#1177108)
* Thu Sep  3 2020 jsrain@suse.com
- replace kubic-locale-archive with glibc-locale-base (bsc#1176079)
* Tue Sep  1 2020 jsrain@suse.com
- make dependency of grub2-branding-SLE hard
- bump version to 5.0.0
* Fri Aug 28 2020 jsrain@suse.com
- recommend grub2-branding-SLE by base pattern
* Thu Aug 13 2020 jsrain@suse.com
- clean-up of patterns, more consistent pattern naming
* Tue Aug 11 2020 jsrain@suse.com
- fixed wrong package names, removed unneeded patterns
* Mon Aug 10 2020 jsrain@suse.com
- initial version
